@@ -1,5 +1,4 @@
 from django.contrib.contenttypes.models import ContentType
-from django.test.utils import override_settings
 from entity.models import Entity
 
 from .models import Account, Team, TeamGroup, Competitor
@@ -477,34 +476,11 @@ class TestEntityModel(EntityTestCase):
         # Verify that the sub entities of the team is the account
         self.assertEquals(list(team_entity.get_sub_entities()), [account_entity])
 
-    def test_unicode_default_missing(self):
+    def test_unicode(self):
         """
-        Tests that if we can't find a better representation, we have a default __unicode__.
+        Tests that the unicode method returns the display name of the entity.
         """
-        account = Account.objects.create()
+        account = Account.objects.create(email='hi')
         entity = Entity.objects.get_for_obj(account)
         entity_unicode = entity.__unicode__()
-        self.assertEquals(entity_unicode, 'Entity Object')
-
-    @override_settings(ENTITY_NAME_KEYS=('something', 'email', 'something else'))
-    def test_unicode_from_settings(self):
-        """
-        Tests that, of the provided ENTITY_NAME_KEYS, the one that exists in entity_meta is used.
-        """
-        account = Account.objects.create(email="account@example.com")
-        entity = Entity.objects.get_for_obj(account)
-        entity_unicode = entity.__unicode__()
-        self.assertEquals(entity_unicode, 'account@example.com')
-
-    def test_unicode_null_entity_meta(self):
-        """
-        If entity_meta is null, __unicode__ should not fail.
-        """
-        account_ct = ContentType.objects.get_for_model(Account)
-        e = Entity.objects.create(
-            entity_id=1,
-            entity_type=account_ct,
-            entity_meta=None,
-        )
-        entity_unicode = e.__unicode__()
-        self.assertEquals(entity_unicode, 'Entity Object')
+        self.assertEquals(entity_unicode, 'hi')
